@@ -55,7 +55,7 @@ pub enum FileState {
 }
 
 #[derive(Debug, Deserialize, PartialEq, Serialize)]
-#[serde(rename_all = "lowercase", tag = "type")]
+#[serde(default, rename_all = "lowercase", tag = "type")]
 pub struct File {
     pub force: Option<bool>,
     pub path: PathBuf,
