@@ -59,13 +59,23 @@ impl PartialEq for Error {
 }
 
 #[derive(Debug, Deserialize, PartialEq, Serialize)]
-#[serde(rename_all = "lowercase", tag = "type")]
+#[serde(default, rename_all = "lowercase", tag = "type")]
 pub struct Git {
+    /// Should we clone [`repo`](Git::repo) if it does not yet exist at [`depth`](Git::depth)?
+    /// Default = yes.
     pub clone: Option<bool>,
+    /// Limit fetching to a specified number of commits in history per [`git fetch --depth=N`](https://git-scm.com/docs/fetch-options#Documentation/fetch-options.txt---depthltdepthgt).
+    /// Default = no limit, complete history.
     pub depth: Option<NonZeroU32>,
+    /// Checkout [`repo`](Git::repo) into this target path.
     pub dest: PathBuf,
     // refspec: String
+    /// Should we delete any unexpected files at [`dest`](Git::dest) if necessary?
+    /// Default = no, exit early with an error instead of deleting files.
     pub force: Option<bool>,
+    /// Should we pull newer commits from the origin?
+    /// Default = yes, keep [`dest`](Git::dest) up to date.
+    pub update: Option<bool>,
     #[serde(
         deserialize_with = "from_toml_git_url",
         serialize_with = "to_toml_git_url"
@@ -81,6 +91,7 @@ impl Default for Git {
             force: None,
             repo: git_url::parse("https://gitlab.com/".as_bytes())
                 .expect("unable to parse default URL"),
+            update: Some(true),
         }
     }
 }
@@ -106,8 +117,12 @@ impl Git {
             if is_git_repository(&self.dest)
                 && is_git_url_eq(&git_origin_remote_url(&self.dest)?, &self.repo)
             {
+                if !self.update.unwrap_or(true) {
+                    return Ok(Status::NoChange(current_commit(&self.dest)?));
+                }
                 return self.git_pull();
-            } else if self.force.unwrap_or(false) {
+            }
+            if self.force.unwrap_or(false) {
                 before = String::from("not repository");
                 if self.dest.is_dir() {
                     fs::remove_dir_all(&self.dest)?;
